SqlPyGen: Generated Type Annotated Python from Annotated SQL
============================================================

sqlpygen is a utility to generate
type annotated Python code from annotated SQL.
This is in part motivated by sqlc_ project.

The current version of the tool only supports
generating code for SQLite3.

Please check the ``examples`` directroy
for examples of code generated by the utility.

.. _sqlc: https://github.com/kyleconroy/sqlc
